@@ -10,10 +10,8 @@ class CDAElement(object):
     def __new__(cls, element):
         cda = etree.Element(
             etree.QName(PRAXIS_NS, 'generaCda'),
-            nsmap={None: PRAXIS_NS},
         )
-        mensaje = etree.tostring(element, xml_declaration=False, encoding='cp850')
-        cda.text = mensaje
+        cda.append(element)
         return cda
 
 
