@@ -3,12 +3,20 @@ from lxml import etree
 from spei.resources import Acuse
 
 
-class MensajeElement(object):
+class XMLElement(object):
+    def __new__(cls, respuesta):
+        xml_element = respuesta.find(
+            'xml',
+        )
+
+        return etree.fromstring(xml_element.text)  # noqa: S320
+
+
+class RespuestaElement(object):
     def __new__(cls, body):
-        mensaje = body.find(
+        return body.find(
             '{http://cep.fyg.com/}respuestaCDA',
         )
-        return etree.fromstring(mensaje.text)  # noqa: S320
 
 
 class BodyElement(object):
@@ -21,5 +29,5 @@ class BodyElement(object):
 class AcuseResponse(object):
     def __new__(cls, acuse, acuse_cls=Acuse):
         mensaje = etree.fromstring(acuse)  # noqa: S320
-        mensaje_element = MensajeElement(BodyElement((mensaje)))
+        mensaje_element = XMLElement(RespuestaElement(BodyElement((mensaje))))
         return acuse_cls.parse_xml(mensaje_element)
